==> angular2-in-memory-web-api-0.0.15.jar: META-INF/resources/webjars/angular2-in-memory-web-api/0.0.15/CHANGELOG.md <==
<a name="0.0.15"></a>
# 0.0.15 (2016-08-09)
* RC5
* Support for NgModules

<a name="0.0.14"></a>
# 0.0.14 (2016-06-30)
* RC4

<a name="0.0.13"></a>
# 0.0.13 (2016-06-21)
* RC3

<a name="0.0.12"></a>
# 0.0.12 (2016-06-15)
* RC2

<a name="0.0.11"></a>
# 0.0.11 (2016-05-27)
* add RegExp query support
* find-by-id is sensitive to string ids that look like numbers

<a name="0.0.10"></a>
# 0.0.10 (2016-05-21)
* added "main:index.js" to package.json
* updated to typings v.1.0.4 (a breaking release)
* dependencies -> peerDependencies|devDependencies
* no es6-shim dependency.
* use core-js as devDependency.

<a name="0.0.9"></a>
# 0.0.9 (2016-05-19)
* renamed the barrel core.js -> index.js

<a name="0.0.8"></a>
# 0.0.8 (2016-05-19)
* systemjs -> commonjs
* replace es6-shim typings w/ core-js typings

<a name="0.0.7"></a>
# 0.0.7 (2016-05-03)
* RC1
* update to 2.0.0-rc.1

<a name="0.0.6"></a>
# 0.0.6 (2016-05-03)
* RC0
* update to 2.0.0-rc.0

<a name="0.0.5"></a>
# 0.0.5 (2016-05-01)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-5

<a name="0.0.4"></a>
# 0.0.4 (2016-04-30)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-3
* rxjs: "5.0.0-beta.6"

<a name="0.0.3"></a>
# 0.0.3 (2016-04-29)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-2

<a name="0.0.2"></a>
# 0.0.2 (2016-04-27)
* PROVISIONAL - refers to @angular packages

<a name="0.0.1"></a>
# 0.0.1 (2016-04-27)
* DO NOT USE. Not adapted to new package system.
* Initial cut for Angular 2 repackaged
  * target forthcoming Angular 2 RC

==> angular2-in-memory-web-api-0.0.17.jar: META-INF/resources/webjars/angular2-in-memory-web-api/0.0.17/CHANGELOG.md <==
<a name="0.0.17"></a>
# 0.0.17 (2016-08-19)
* fix `forRoot` type constraint
* clarify `forRoot` param

<a name="0.0.16"></a>
# 0.0.16 (2016-08-19)
* No longer exports `HttpModule`
* Can specify configuration options in 2nd param of `forRoot`
* jsDocs for `forRoot`

<a name="0.0.15"></a>
# 0.0.15 (2016-08-09)
* RC5
* Support for NgModules

<a name="0.0.14"></a>
# 0.0.14 (2016-06-30)
* RC4

<a name="0.0.13"></a>
# 0.0.13 (2016-06-21)
* RC3

<a name="0.0.12"></a>
# 0.0.12 (2016-06-15)
* RC2

<a name="0.0.11"></a>
# 0.0.11 (2016-05-27)
* add RegExp query support
* find-by-id is sensitive to string ids that look like numbers

<a name="0.0.10"></a>
# 0.0.10 (2016-05-21)
* added "main:index.js" to package.json
* updated to typings v.1.0.4 (a breaking release)
* dependencies -> peerDependencies|devDependencies
* no es6-shim dependency.
* use core-js as devDependency.

<a name="0.0.9"></a>
# 0.0.9 (2016-05-19)
* renamed the barrel core.js -> index.js

<a name="0.0.8"></a>
# 0.0.8 (2016-05-19)
* systemjs -> commonjs
* replace es6-shim typings w/ core-js typings

<a name="0.0.7"></a>
# 0.0.7 (2016-05-03)
* RC1
* update to 2.0.0-rc.1

<a name="0.0.6"></a>
# 0.0.6 (2016-05-03)
* RC0
* update to 2.0.0-rc.0

<a name="0.0.5"></a>
# 0.0.5 (2016-05-01)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-5

<a name="0.0.4"></a>
# 0.0.4 (2016-04-30)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-3
* rxjs: "5.0.0-beta.6"

<a name="0.0.3"></a>
# 0.0.3 (2016-04-29)
* PROVISIONAL - refers to @angular packages
* update to 0.0.0-2

<a name="0.0.2"></a>
# 0.0.2 (2016-04-27)
* PROVISIONAL - refers to @angular packages

<a name="0.0.1"></a>
# 0.0.1 (2016-04-27)
* DO NOT USE. Not adapted to new package system.
* Initial cut for Angular 2 repackaged
  * target forthcoming Angular 2 RC
